@@ -36,30 +36,78 @@ class fillVars(object, cl_base.glob_attr):
 
     def get_os_linux_shortname(self):
         '''Получить переменную короткого названия системы'''
-        path = '/etc/issue'
-        sp="""Welcome to \\\\n.\\\\O \(([a-zA-Z ]+) ([^\s\)]+)"""
-        res=self._runos('%scat %s | grep "Welcome to "'%\
-                (self.path_env, path))
-        dist_ver = {'CLD':"Calculate Linux Desktop",
-                    'CDS':"Calculate Directory Server",
-                    'AcoolA':"Calculate Web Server"}
-        if res:
-            if re.search(sp,res):
-                vals=re.search(sp,res).groups()
-                issuename=vals[0]
-                for i in dist_ver.keys():
-                    if dist_ver[i]==issuename:
-                        return i
-                spl=issuename.split(" ")
-                nname=""
-                if len(spl)>1:
-                    for i in spl:
-                        nname+=i[1]
-                    return nname
-                else:
-                    return issuename
-        return "CLD"
+        path = '/etc/calculate/calculate.ini'
+        if os.path.exists(path):
+            FD = open(path)
+            data = FD.readlines()
+            FD.close()
+            shortNameList = filter(lambda y:y,
+                                   map(lambda x:\
+                                       len(x.split("="))==2 and\
+                                       x.split("=")[0]=="calculate" and\
+                                       x.split("=")[1].strip(), data))
+            if shortNameList:
+                return shortNameList[0]
+        gentooFile = "/etc/gentoo-release"
+        shortName = "Linux"
+        if os.path.exists(gentooFile):
+            shortName = "Gentoo"
+        return shortName
 
+    def get_os_linux_name(self):
+        """полное название системы"""
+        linuxShortName = self.Get("os_linux_shortname")
+        if linuxShortName:
+            dictLinuxName = {"CLD":"Calculate Linux Desktop",
+                             "CLDX":"Calculate Linux Desktop",
+                             "CDS":"Calculate Directory Server",
+                             "Gentoo":"Gentoo"}
+            if linuxShortName in dictLinuxName.keys():
+                return dictLinuxName[linuxShortName]
+            else:
+                return "Linux"
+        else:
+            return "Linux"
+
+    def get_os_linux_subname(self):
+        """постфикс к названию системы"""
+        linuxShortName = self.Get("os_linux_shortname")
+        if linuxShortName:
+            dictLinuxSubName = {"CLD":"KDE", "CLDX":"XFCE"}
+            if linuxShortName in dictLinuxSubName.keys():
+                return dictLinuxSubName[linuxShortName]
+            else:
+                return ""
+        else:
+            return ""
+
+    def get_os_linux_ver(self):
+        '''Получить версию системы'''
+        path = '/etc/calculate/calculate.ini'
+        if os.path.exists(path):
+            FD = open(path)
+            data = FD.readlines()
+            FD.close()
+            shortNameList = filter(lambda y:y,
+                                   map(lambda x:\
+                                       len(x.split("="))==2 and\
+                                       x.split("=")[0]=="linuxver" and\
+                                       x.split("=")[1].strip(), data))
+            if shortNameList:
+                return shortNameList[0]
+        gentooFile = "/etc/gentoo-release"
+        systemVersion = ""
+        flagGentoo = False
+        if os.path.exists(gentooFile):
+            gentooLink = "/etc/make.profile"
+            if os.path.islink(gentooLink):
+                systemVersion = os.readlink(gentooLink).rpartition("/")[2]
+                flagGentoo = True
+        if not flagGentoo:
+            kernelVersion=self._runos("%s uname -r"%self.path_env)
+            if kernelVersion:
+                systemVersion = kernelVersion.partition("-")[0]
+        return systemVersion
 
     def get_os_net_hostname(self):
         '''Считать имя компьютера net_host'''
@@ -134,6 +182,37 @@ class fillVars(object, cl_base.glob_attr):
 
     def get_os_locale_xkb(self):
         """раскладка клавиатуры для X"""
+        path = '/etc/conf.d/keymaps'
+        mapDict={"by":"us,by",
+                 "be-latin1":"be,us",
+                 "br-abnt2":"br,us",
+                 "cf":"ca,us",
+                 "dk-latin1":"dk,us",
+                 "fr-latin9":"fr,us",
+                 "de-latin1":"de,us",
+                 "is-latin1":"is,us",
+                 "it":"it,us",
+                 "no-latin1":"no,us",
+                 "pl":"pl,us",
+                 "-u ru4":"us,ru(winkeys)",
+                 "es euro2":"es,us",
+                 "sv-latin1":"se,us",
+                 "ua-utf":"us,ua(winkeys)",
+                 "uk":"gb,us",
+                 "us":"us"}
+        if os.path.exists(path):
+            FD = open(path)
+            data = FD.readlines()
+            FD.close()
+            shortNameList = filter(lambda y:y,
+                                   map(lambda x:\
+                                       len(x.split("="))==2 and\
+                                       x.split("=")[0]=="KEYMAP" and\
+                                       x.split("=")[1].replace('"',"").strip(),\
+                                       data))
+            if shortNameList:
+                if shortNameList[0] in mapDict.keys():
+                    return mapDict[shortNameList[0]]
         lang = self.Get("os_locale_lang")
         # Языки: 
         # Португальский - pt_BR
@@ -144,12 +223,12 @@ class fillVars(object, cl_base.glob_attr):
         # Украинский    - uk_UA
         # Английский    - en_US
         xkbDict = {'pt_BR':'br,us',
-                   'fr_FR':'fr,us',
-                   'de_DE':'de,us',
-                   'ru_RU':'us,ru(winkeys)',
-                   'es_ES':'es,us',
-                   'uk_UA':'us,ua(winkeys)',
-                   'en_US':'us'}
+                'fr_FR':'fr,us',
+                'de_DE':'de,us',
+                'ru_RU':'us,ru(winkeys)',
+                'es_ES':'es,us',
+                'uk_UA':'us,ua(winkeys)',
+                'en_US':'us'}
         if lang:
             if xkbDict.has_key(lang):
                 return xkbDict[lang]
