@@ -61,6 +61,9 @@ class Data:
     # архитектура компьютера (i686,x86_64)
     os_arch_machine = {}
 
+    #проход при наложении профилей 1,2,3,4,5 и.т д
+    cl_pass_step = {'mode':"w"}
+
     # обрабатываемый файл профиля
     cl_pass_file = {'mode':"w"}
 
@@ -68,4 +71,13 @@ class Data:
     os_root_dev = {}
 
     # тип носителя (ram, hdd, usb-hdd, livecd)
-    os_root_type = {}
\ No newline at end of file
+    os_root_type = {}
+
+    # полное название системы
+    os_linux_name = {}
+
+    # постфикс к названию системы
+    os_linux_subname = {}
+
+    # версия системы
+    os_linux_ver = {}
